==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/LineFragmentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FragmentBaseDescriptionMetadata } from "./FragmentBaseDescriptionMetadata";
import { LineFragmentDescription } from "./LineFragmentDescription";
/**
 * @hidden
 */
export let LineFragmentDescriptionMetadata = /*@__PURE__*/ (() => {
    class LineFragmentDescriptionMetadata extends Base {
        static b(a) {
            if (LineFragmentDescriptionMetadata.a == null) {
                LineFragmentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                LineFragmentDescriptionMetadata.c(LineFragmentDescriptionMetadata.a);
            }
            if (a.j(LineFragmentDescriptionMetadata.a)) {
                return;
            }
            a.y(LineFragmentDescriptionMetadata.a);
        }
        static c(a) {
            FragmentBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            LineFragmentDescriptionMetadata.b(a);
            a.aa("LineFragment", () => new LineFragmentDescription());
            a.z("LineFragment", LineFragmentDescriptionMetadata.a);
        }
    }
    LineFragmentDescriptionMetadata.$t = /*@__PURE__*/ markType(LineFragmentDescriptionMetadata, 'LineFragmentDescriptionMetadata');
    LineFragmentDescriptionMetadata.a = null;
    return LineFragmentDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/LineFragmentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FragmentBaseDescriptionMetadata } from "./FragmentBaseDescriptionMetadata";
import { LineFragmentDescription } from "./LineFragmentDescription";
/**
 * @hidden
 */
export let LineFragmentDescriptionMetadata = /*@__PURE__*/ (() => {
    class LineFragmentDescriptionMetadata extends Base {
        static b(a) {
            if (LineFragmentDescriptionMetadata.a == null) {
                LineFragmentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                LineFragmentDescriptionMetadata.c(LineFragmentDescriptionMetadata.a);
            }
            if (a.k(LineFragmentDescriptionMetadata.a)) {
                return;
            }
            a.aa(LineFragmentDescriptionMetadata.a);
        }
        static c(a) {
            FragmentBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            LineFragmentDescriptionMetadata.b(a);
            a.ac("LineFragment", () => new LineFragmentDescription());
            a.ab("LineFragment", LineFragmentDescriptionMetadata.a);
        }
    }
    LineFragmentDescriptionMetadata.$t = /*@__PURE__*/ markType(LineFragmentDescriptionMetadata, 'LineFragmentDescriptionMetadata');
    LineFragmentDescriptionMetadata.a = null;
    return LineFragmentDescriptionMetadata;
})();
